@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: m3Func.php 3431 2010-07-27 06:43:26Z fishbone $
+ * @version    SVN: $Id: m3Func.php 3551 2010-08-30 07:18:13Z fishbone $
  * @link       http://www.magic3.org
  */
 /**
@@ -479,6 +479,32 @@ function parseUrlParam($src)
 	}
 	return $dest;
 }
+/**
+ * ディレクトリのファイル使用サイズを求める
+ *
+ * @param string $path		ディレクトリのパス
+ * @return int				ディレクトリサイズ(バイト)
+ */
+function calcDirSize($path)
+{
+	$size = 0;		// ディスク使用サイズ
+	
+	if ($dirHandle = @opendir($path)){
+		while ($file = @readdir($dirHandle)) {
+			if ($file == '.' || $file == '..') continue;
+		
+			// ディレクトリのときはサブディレクトリを計算
+			$filePath = $path . '/' . $file;
+			if (is_dir($filePath)){
+				$size += calcDirSize($filePath);
+			} else {
+				$size += @filesize($filePath);
+			}
+		}
+		closedir($dirHandle);
+	}
+	return $size;
+}
 /**
  * 文字列メモリ表現から数値メモリ表現を取得
  *
@@ -509,14 +535,14 @@ function convFromBytes($val)
 {
 	$destVal = (float)$val / 1024.0;
 	if ($destVal < 1024){
-		return $destVal . 'K';
+		return ceil($destVal) . 'K';
 	}
 	$destVal = $destVal / 1024.0;
 	if ($destVal < 1024){
-		return $destVal . 'M';
+		return ceil($destVal) . 'M';
 	}
 	$destVal = $destVal / 1024.0;
-	return $destVal . 'G';
+	return ceil($destVal) . 'G';
 }
 /**
  * URL以外をエンティティ文字に変換
