@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: scriptLibInfo.php 3660 2010-10-01 12:41:57Z fishbone $
+ * @version    SVN: $Id: scriptLibInfo.php 3710 2010-10-18 02:57:50Z fishbone $
  * @link       http://www.magic3.org
  */
 class ScriptLibInfo
@@ -45,11 +45,13 @@ class ScriptLibInfo
 	const LIB_JQUERY_PRETTYPHOTO	= 'jquery.prettyphoto';
 	const LIB_JQUERY_QTIP			= 'jquery.qtip';
 	const LIB_JQUERY_CALCULATION	= 'jquery.calculation';
+	const LIB_JQUERY_JQPLOT			= 'jquery.jqplot';
 	
 	// jQueryプラグインバージョン
 	const JQUERY_PRETTYPHOTO_VER	= '2.5.6';
 	const JQUERY_QTIP_VER			= '1.0';
 	const JQUERY_CALCULATION_VER	= '0.4.07';
+	const JQUERY_JQPLOT_VER			= '0.9.7';
 	
 	// jQuery UI
 	const LIB_JQUERY_UI_WIDGETS_ACCORDION		= 'jquery-ui.accordion';		// Widgets Accordion
@@ -90,6 +92,9 @@ class ScriptLibInfo
 	const JQUERY_PRETTYPHOTO_CSS		= 'jquery/prettyPhoto/css/prettyPhoto.css';
 	const JQUERY_QTIP_FILENAME			= 'jquery/jquery.qtip-1.0.min.js';
 	const JQUERY_CALCULATION_FILENAME	= 'jquery/jquery.calculation.js';
+	const JQUERY_JQPLOT_FILENAME		= 'jquery/jqplot/jquery.jqplot.min.js';
+//	const JQUERY_JQPLOT_EX_FILENAME		= 'jquery/jqplot/excanvas.min.js';
+	const JQUERY_JQPLOT_CSS				= 'jquery/jqplot/jquery.jqplot.css';
 	
 	// ライブラリの公式サイトのURL
 	const JQUERY_CLUETIP_URL			= 'http://plugins.learningjquery.com/cluetip/';
@@ -98,6 +103,7 @@ class ScriptLibInfo
 	const JQUERY_PRETTYPHOTO_URL		= 'http://www.no-margin-for-errors.com/projects/prettyphoto-jquery-lightbox-clone/';
 	const JQUERY_QTIP_URL				= 'http://craigsworks.com/projects/qtip/';
 	const JQUERY_CALCULATION_URL		= 'http://www.pengoworks.com/workshop/jquery/calculation/calculation.plugin.htm';
+	const JQUERY_JQPLOT_URL				= 'http://www.jqplot.com/';
 	
 	// ディレクトリ名
 	const FCKEDITOR_DIRNAME				= 'fckeditor2.6.6';				// FCKEditor
@@ -222,7 +228,11 @@ class ScriptLibInfo
 																'version'	=>	self::JQUERY_QTIP_VER),
 					self::LIB_JQUERY_CALCULATION	=>	array(	'script' 	=> array(self::JQUERY_CALCULATION_FILENAME),	// jquery.calculation用のファイル
 																'url'		=>	self::JQUERY_CALCULATION_URL,
-																'version'	=>	self::JQUERY_CALCULATION_VER)
+																'version'	=>	self::JQUERY_CALCULATION_VER),
+					self::LIB_JQUERY_JQPLOT			=>	array(	'script' 	=> array(self::JQUERY_JQPLOT_FILENAME),	// jquery.jqplot用のファイル
+																'css'		=>	array(self::JQUERY_JQPLOT_CSS),
+																'url'		=>	self::JQUERY_JQPLOT_URL,
+																'version'	=>	self::JQUERY_JQPLOT_VER)
 																);
 					
 		// 使用するjQueryバージョンに合わせてファイルを追加
