@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2009 Magic3 Project.
+ * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: instanceManager.php 2660 2009-12-13 07:26:11Z fishbone $
+ * @version    SVN: $Id: instanceManager.php 3630 2010-09-25 01:23:58Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/systemDb.php');		// システムDBアクセスクラス
@@ -93,7 +93,7 @@ class InstanceManager extends Core
 		$addonObj = $this->addonArray[$id];
 		if (!isset($addonObj)){			// 取得されていないとき
 			// アドオンをロード
-			self::loadAddonClass();
+			$this->loadAddonClass();
 			$addonObj = $this->addonArray[$id];
 		}
 		return $addonObj;
