@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: textConvManager.php 3730 2010-10-24 15:13:05Z fishbone $
+ * @version    SVN: $Id: textConvManager.php 3759 2010-10-29 12:57:09Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/htmlEdit.php');
@@ -31,7 +31,6 @@ class TextConvManager extends Core
 	 */
 	function __construct()
 	{
-		//global $gInstanceManager;
 		// 親クラスを呼び出す
 		parent::__construct();
 		
@@ -266,9 +265,11 @@ class TextConvManager extends Core
 		$this->contentDt = $contentDt;
 		$dest = $src;
 		
-		// 画像を携帯用に作成
-		$str = '/<img[^<]*?src\s*=\s*[\'"]+(.+?)[\'"]+[^>]*?>/si';
-		$dest = preg_replace_callback($str, array($this, "_replace_to_mobile_callback"), $dest);
+		// 表示しないタグを削除。データ量を減らす。
+		$removeTags = array('script', 'style', 'iframe', 'noframes?');
+		foreach ($removeTags as $value){
+			$dest = preg_replace('/<'.$value.'\b[^>]*?>.*?<\/'.$value.'\b[^>]*?>/si', '', $dest);
+		}
 		
 		// テーブルタグを除く
 		$dest = $this->deleteTag($dest, 'table');
@@ -276,6 +277,7 @@ class TextConvManager extends Core
 		$dest = $this->deleteTag($dest, 'thead');
 		$dest = $this->deleteTag($dest, 'tfoot');
 		$dest = $this->deleteTag($dest, 'tr');
+		
 		// TH,TDタグをDIVに変換
 		$dest = preg_replace('/<th\b[^>]*?>/si', '<div>', $dest);
 		$dest = preg_replace('/<\/th\b[^>]*?>/si', '</div>', $dest);
@@ -287,6 +289,9 @@ class TextConvManager extends Core
 		$dest = preg_replace('/<\/p\b[^>]*?>/si', '</div>', $dest);
 		$dest = preg_replace('/<div>\s*<\/div>/si', '', $dest);		// 空のDIVタグ削除
 		
+		// PREタグの処理
+		$dest = preg_replace_callback('/<pre\b[^>]*?>(.*?)<\/pre\b[^>]*?>/si', create_function('$matches', 'return "<div>".nl2br(trim($matches[1]))."</div>";'), $dest);
+		
 		// 連続したタグをまとめる
 		$search = array(
 			"'(?:<hr\b[^>]*?>\s*){2,}'si",
@@ -297,10 +302,14 @@ class TextConvManager extends Core
 			"<br /><br />"
 		);
 		$dest = preg_replace($search, $replace, $dest);
+		
+		// 画像を携帯用に作成
+		$str = '/<img[^<]*?src\s*=\s*[\'"]+(.+?)[\'"]+[^>]*?>/si';
+		$dest = preg_replace_callback($str, array($this, "_replace_to_mobile_callback"), $dest);
 		return $dest;
 	}
 	/**
-	 * Magic3絵文字タグ変換コールバック関数
+	 * IMGタグ変換コールバック関数
 	 *
 	 * @param array $matchData		検索マッチデータ
 	 * @return string				変換後データ
@@ -330,7 +339,7 @@ class TextConvManager extends Core
 				$destImageRelativePath = dirname(substr($relativePath, strlen($resDir))) . '/' . $destImageFilename;
 				$destImageFile = $gEnvManager->getResourcePath() . '/widgets/' . $this->contentType . '/' . M3_DIR_NAME_MOBILE . '/' . $destImageRelativePath;
 				$destImageUrl = $gEnvManager->getResourceUrl() . '/widgets/' . $this->contentType . '/' . M3_DIR_NAME_MOBILE . '/' . $destImageRelativePath;
-																
+
 				// ファイルと日時をチェック
 				$createImage = true;
 				if (file_exists($destImageFile) && strtotime($this->contentDt) < filemtime($destImageFile)){
@@ -400,6 +409,101 @@ class TextConvManager extends Core
 		}
 		return $destTag;
     }
+	/**
+	 * 携帯用のHTMLをきれいにする
+	 *
+	 * 以下の自動変換処理を行う
+	 *  ・HTML4仕様のタグをXHTML仕様に変換
+	 *
+	 * @param string $src			変換するデータ
+	 * @return string				変換後データ
+	 */
+	function cleanMobileTag($src)
+	{
+		$dest = $src;
+		$dest = preg_replace('/<blink>(.*?)<\/blink>/si', '<span style="text-decoration:blink;">$1</span>', $dest);
+		$dest = preg_replace('/<center>(.*?)<\/center>/si', '<div style="text-align:center;">$1</div>', $dest);
+		$str = '/<font\b(.*?)>(.*?)<\/font\b[^>]*?>/si';
+		$dest = preg_replace_callback($str, array($this, '_replace_font_callback'), $dest);
+		
+		// MARQUEEタグの変換
+		$str = '/<marquee\b(.*?)>(.*?)<\/marquee\b[^>]*?>/si';
+		$dest = preg_replace_callback($str, array($this, '_replace_markquee_callback'), $dest);
+		return $dest;
+	}
+	/**
+	 * FONTタグ変換コールバック関数
+	 *
+	 * @param array $matchData		検索マッチデータ
+	 * @return string				変換後データ
+	 */
+    function _replace_font_callback($matchData)
+	{
+		// 属性をスタイル属性に直す
+		$style = '';
+		$str = '/color\s*=\s*[\'"]+(.+?)[\'"]/si';		// 文字色
+		if (preg_match($str, $matchData[1], $matches)) $style .= 'color:' . $matches[1] . ';';
+		$str = '/size\s*=\s*[\'"]+(.+?)[\'"]/si';		// 文字サイズ
+		if (preg_match($str, $matchData[1], $matches)){
+			if (strStartsWith($matches[1], '+')){
+				$fontSize = 'larger';
+			} else if (strStartsWith($matches[1], '-')){
+				$fontSize = 'smaller';
+			} else {
+				switch ($matches[1]){
+					case 1:
+						$fontSize = 'xx-small';
+						break;
+					case 2:
+						$fontSize = 'x-small';
+						break;
+					case 3:
+						$fontSize = 'small';
+						break;
+					case 4:
+						$fontSize = 'medium';
+						break;
+					case 5:
+						$fontSize = 'large';
+						break;
+					case 6:
+						$fontSize = 'x-large';
+						break;
+					case 7:
+						$fontSize = 'xx-large';
+						break;
+					default:
+						$fontSize = $matches[1];
+						break;
+				}
+			}
+			$style .= 'font-size:' . $fontSize . ';';
+		}
+		$destTag = '<span style="' . $style . '">' . $matchData[2] . '</span>';
+		return $destTag;
+	}
+	/**
+	 * MARQUEEタグ変換コールバック関数
+	 *
+	 * @param array $matchData		検索マッチデータ
+	 * @return string				変換後データ
+	 */
+    function _replace_markquee_callback($matchData)
+	{
+		// 属性をスタイル属性に直す
+		$style = 'display:-wap-marquee;';
+		$str = '/bgcolor\s*=\s*[\'"]+(.+?)[\'"]/si';		// 背景色
+		if (preg_match($str, $matchData[1], $matches)) $style .= 'background-color:' . $matches[1] . ';';
+		$str = '/behavior\s*=\s*[\'"]+(.+?)[\'"]/si';		// マーキースタイル
+		if (preg_match($str, $matchData[1], $matches)) $style .= '-wap-marquee-style:' . $matches[1] . ';';
+		$str = '/direction\s*=\s*[\'"]+(.+?)[\'"]/si';		// 表示方向
+		if (preg_match($str, $matchData[1], $matches)) $style .= '-wap-marquee-dir:' . $matches[1] . ';';
+		$str = '/loop\s*=\s*[\'"]+(.+?)[\'"]/si';		// 回数
+		if (preg_match($str, $matchData[1], $matches)) $style .= '-wap-marquee-loop:' . $matches[1] . ';';
+		
+		$destTag = '<span style="' . $style . '">' . $matchData[2] . '</span>';
+		return $destTag;
+	}
 	/**
 	 * HTMLをテキストに変換
 	 *
