@@ -11,7 +11,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: index.php 3597 2010-09-17 01:41:17Z fishbone $
+ * @version    SVN: $Id: index.php 3747 2010-10-27 07:58:11Z fishbone $
  * @link       http://www.magic3.org
  */
 // 直接アクセスの防止
@@ -38,6 +38,8 @@ $HELP['configsite_description']['title'] = 'ページ要約';
 $HELP['configsite_description']['body'] = 'ヘッダ部のdescriptionタグに設定される文字列です。120文字程度で記述します。<br />Googleでは検索結果に表示されます。';
 $HELP['configsite_keywords']['title'] = '検索キーワード';
 $HELP['configsite_keywords']['body'] = 'ヘッダ部のkeywordsタグに設定される文字列です。検索エンジン用のキーワードを「,」区切りで10個以下で記述します。';
+$HELP['configsite_google_maps_key']['title'] = 'Googleマップ利用キー';
+$HELP['configsite_google_maps_key']['body'] = 'サイトで表示するGoogleマップの利用キーを設定します。設定するとコンテンツ編集エディタ(FCKEditor)からGoogleマップを使用することが可能になります。';
 
 // ########## システム情報 ##########
 $HELP['configsys']['title'] = 'システム基本設定';
