@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_bbs_2ch_mainWidgetContainer.php 2930 2010-03-17 14:19:10Z fishbone $
+ * @version    SVN: $Id: admin_bbs_2ch_mainWidgetContainer.php 3274 2010-06-22 06:22:06Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_bbs_2ch_mainBaseWidgetContainer.php');
@@ -44,12 +44,11 @@ class admin_bbs_2ch_mainWidgetContainer extends admin_bbs_2ch_mainBaseWidgetCont
 		// コンテナを起動
 		$goWidget = false;		// サブウィジェットを実行するかどうか
 		switch ($task){
-			/*case 'content':		// コンテンツ管理
-			case 'content_detail':		// コンテンツ管理(詳細)
-			case 'add_to_menu':	// コンテンツへのリンクをメニューに追加
-				$task = 'content';
+			case 'message':		// メッセージ管理
+			case 'message_detail':		// メッセージ管理(詳細)
+				$task = 'message';
 				$goWidget = true;		// サブウィジェットを実行するかどうか
-				break;*/
+				break;
 			case 'other':		// その他設定
 				$goWidget = true;		// サブウィジェットを実行するかどうか
 				break;
