@@ -9,9 +9,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2009 Magic3 Project.
+ * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: index.php 2452 2009-10-22 11:47:08Z fishbone $
+ * @version    SVN: $Id: index.php 3614 2010-09-22 05:09:39Z fishbone $
  * @link       http://www.magic3.org
  */
 // 直接アクセスの防止
@@ -38,6 +38,8 @@ $HELP['entry_category']['title'] = 'カテゴリー';
 $HELP['entry_category']['body'] = 'ブログ記事の分類カテゴリーです。';
 $HELP['entry_user']['title'] = '投稿者';
 $HELP['entry_user']['body'] = 'ブログ記事の投稿者です。';
+$HELP['entry_blogid']['title'] = '所属ブログ';
+$HELP['entry_blogid']['body'] = 'マルチブログの場合の所属ブログです。';
 $HELP['entry_dt']['title'] = '投稿日時';
 $HELP['entry_dt']['body'] = 'ブログ記事の投稿日時です。<br />投稿日時を未来に設定した場合は、その日時までユーザからは閲覧できません。';
 $HELP['entry_active_term']['title'] = '公開期間';
@@ -119,6 +121,38 @@ $HELP['category_index']['body'] = 'カテゴリーを一覧表示する際の表
 $HELP['category_visible']['title'] = '公開';
 $HELP['category_visible']['body'] = 'カテゴリーをユーザに公開するかどうかを制御します。';
 
+// ########## マルチブログ管理 ##########
+$HELP['blogid_list']['title'] = 'ブログ一覧';
+$HELP['blogid_list']['body'] = '使用可能なブログの一覧です。';
+$HELP['blogid_detail']['title'] = 'ブログ詳細';
+$HELP['blogid_detail']['body'] = 'ブログについての設定を行います。';
+$HELP['blogid_check']['title'] = '選択用チェックボックス';
+$HELP['blogid_check']['body'] = '編集や削除を行う項目を選択します。';
+$HELP['blogid_name']['title'] = '名前';
+$HELP['blogid_name']['body'] = 'ブログの名前です。';
+$HELP['blogid_id']['title'] = 'ブログ識別ID';
+$HELP['blogid_id']['body'] = 'ブログを識別するためにユニークにIDを付けます。';
+$HELP['blogid_visible']['title'] = '公開';
+$HELP['blogid_visible']['body'] = 'ブログを一般ユーザに公開するかどうかを制御します。非公開に設定の場合は一般ユーザから参照することはできません。';
+$HELP['blogid_owner']['title'] = 'ブログ所有者';
+$HELP['blogid_owner']['body'] = 'ブログの所有者です。「投稿ユーザ」以上のレベルのユーザを指定します。ブログの投稿が可能です。';
+$HELP['blogid_template']['title'] = 'テンプレート';
+$HELP['blogid_template']['body'] = 'ブログで使用するテンプレートです。';
+$HELP['blogid_meta_title']['title'] = 'タイトル名';
+$HELP['blogid_meta_title']['body'] = 'ヘッダ部のtitleタグに設定される文字列です。Webブラウザの画面タイトルとして表示されます。';
+$HELP['blogid_meta_description']['title'] = 'ページ要約';
+$HELP['blogid_meta_description']['body'] = 'ヘッダ部のdescriptionタグに設定される文字列です。120文字程度で記述します。<br />Googleでは検索結果に表示されます。';
+$HELP['blogid_meta_keywords']['title'] = '検索キーワード';
+$HELP['blogid_meta_keywords']['body'] = 'ヘッダ部のkeywordsタグに設定される文字列です。検索エンジン用のキーワードを「,」区切りで10個以下で記述します。';
+$HELP['blogid_new_btn']['title'] = '新規ボタン';
+$HELP['blogid_new_btn']['body'] = '新規にブログを追加します。';
+$HELP['blogid_edit_btn']['title'] = '編集ボタン';
+$HELP['blogid_edit_btn']['body'] = '選択されているブログを編集します。<br />項目を選択するには、一覧の左端のチェックボックスにチェックを入れます。';
+$HELP['blogid_del_btn']['title'] = '削除ボタン';
+$HELP['blogid_del_btn']['body'] = '選択されているブログを削除します。<br />項目を選択するには、一覧の左端のチェックボックスにチェックを入れます。';
+$HELP['blogid_ret_btn']['title'] = '戻るボタン';
+$HELP['blogid_ret_btn']['body'] = 'ブログ一覧へ戻ります。';
+
 // ########## ブログ設定 ##########
 $HELP['config_title']['title'] = 'ブログ設定';
 $HELP['config_title']['body'] = 'ブログ全体の設定を行います。';
@@ -126,6 +160,10 @@ $HELP['config_view_count']['title'] = '記事表示数';
 $HELP['config_view_count']['body'] = 'ブログ記事を一覧表示する場合の記事の表示数を設定します。';
 $HELP['config_view_order']['title'] = '記事表示順';
 $HELP['config_view_order']['body'] = 'ブログ記事を一覧表示する場合の記事の表示順を設定します。';
-$HELP['config_receive_comment']['title'] = 'コメントの受付';
+$HELP['config_category_count']['title'] = 'カテゴリ数';
+$HELP['config_category_count']['body'] = '記事に設定可能なカテゴリ数です。';
+$HELP['config_receive_comment']['title'] = 'コメント';
 $HELP['config_receive_comment']['body'] = 'ブログ記事に対して、ユーザからのコメントの受付を許可するかどうかを設定します。';
+$HELP['config_multi_blog_top_content']['title'] = 'マルチブログトップコンテンツ';
+$HELP['config_multi_blog_top_content']['body'] = 'マルチブログを使用した場合のトップ画面のコンテンツです。';
 ?>
