@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_default_contentContentWidgetContainer.php 3090 2010-05-03 06:28:37Z fishbone $
+ * @version    SVN: $Id: admin_default_contentContentWidgetContainer.php 3757 2010-10-29 10:34:41Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_default_contentBaseWidgetContainer.php');
@@ -481,6 +481,9 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 				if (!$ret) break;
 			}
 			if ($ret){
+				// 親ウィンドウを更新
+				$this->gPage->updateParentWindow();
+					
 				$this->setGuidanceMsg('メニューにリンクを追加しました');
 				$this->completed = true;			// データ登録完了かどうか
 			} else {
