@@ -11,7 +11,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: index.php 3576 2010-09-10 03:36:44Z fishbone $
+ * @version    SVN: $Id: index.php 3755 2010-10-29 07:09:55Z fishbone $
  * @link       http://www.magic3.org
  */
 // 直接アクセスの防止
@@ -71,4 +71,6 @@ $HELP['content_ret_btn']['title'] = '戻るボタン';
 $HELP['content_ret_btn']['body'] = 'コンテンツ一覧へ戻ります。';
 $HELP['content_preview_btn']['title'] = 'プレビューボタン';
 $HELP['content_preview_btn']['body'] = 'コンテンツを表示した実際の画面です。';
+$HELP['content_addmenu_btn']['title'] = 'メニューに追加';
+$HELP['content_addmenu_btn']['body'] = 'コンテンツへのリンクをメニューに追加します。';
 ?>
