@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id$
+ * @version    SVN: $Id: admin_ec_mainStockplanWidgetContainer.php 2260 2009-08-27 05:59:32Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_ec_mainBaseWidgetContainer.php');
@@ -38,8 +38,6 @@ class admin_ec_mainStockplanWidgetContainer extends admin_ec_mainBaseWidgetConta
 	 */
 	function __construct()
 	{
-		global $gInstanceManager;
-		
 		// 親クラスを呼び出す
 		parent::__construct();
 		
@@ -47,7 +45,7 @@ class admin_ec_mainStockplanWidgetContainer extends admin_ec_mainBaseWidgetConta
 		$this->productDb = new productDb();
 		$this->customerDb = new ec_customerDb();
 		$this->db = new ec_stockDb();
-		$this->sysDb = $gInstanceManager->getSytemDbObject();
+		$this->sysDb = $this->gInstance->getSytemDbObject();
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -94,11 +92,9 @@ class admin_ec_mainStockplanWidgetContainer extends admin_ec_mainBaseWidgetConta
 	 */
 	function createList($request)
 	{
-		global $gEnvManager;
-		
 		// ユーザ情報、表示言語
-		$userId		= $gEnvManager->getCurrentUserId();
-		$defaultLang	= $gEnvManager->getDefaultLanguage();
+		$userId		= $this->gEnv->getCurrentUserId();
+		$defaultLang	= $this->gEnv->getDefaultLanguage();
 		
 		$this->productId = $request->trimValueOf('productid');	// 商品ID
 		if (empty($this->productId)) $this->productId = 0;
@@ -126,11 +122,9 @@ class admin_ec_mainStockplanWidgetContainer extends admin_ec_mainBaseWidgetConta
 	 */
 	function createDetail($request)
 	{
-		global $gEnvManager;
-
 		// ユーザ情報、表示言語
-		$userId		= $gEnvManager->getCurrentUserId();
-		$defaultLang	= $gEnvManager->getDefaultLanguage();
+		$userId		= $this->gEnv->getCurrentUserId();
+		$defaultLang	= $this->gEnv->getDefaultLanguage();
 		
 		$act = $request->trimValueOf('act');
 		$this->serialNo = $request->trimValueOf('serial');		// 選択項目のシリアル番号
@@ -239,9 +233,6 @@ class admin_ec_mainStockplanWidgetContainer extends admin_ec_mainBaseWidgetConta
 		}
 		// 選択中のシリアル番号を設定
 		$this->tmpl->addVar("_widget", "serial", $this->serialNo);
-		
-		// ディレクトリを設定
-		$this->tmpl->addVar("_widget", "script_url", $gEnvManager->getScriptsUrl());
 	}
 	/**
 	 * 取得したデータをテンプレートに設定する
@@ -253,7 +244,6 @@ class admin_ec_mainStockplanWidgetContainer extends admin_ec_mainBaseWidgetConta
 	 */
 	function stockPlanListLoop($index, $fetchedRow, $param)
 	{
-		global $gEnvManager;
 		static $date = '';		// 日付
 		static $total = 0;		// 合計
 		static $findStart = false;		// 先頭を検出したかどうか
@@ -322,8 +312,6 @@ class admin_ec_mainStockplanWidgetContainer extends admin_ec_mainBaseWidgetConta
 	 */
 	function productListLoop($index, $fetchedRow, $param)
 	{
-		global $gEnvManager;
-
 		$selected = '';
 		if ($fetchedRow['pt_id'] == $this->productId){
 			$selected = 'selected';
@@ -349,8 +337,6 @@ class admin_ec_mainStockplanWidgetContainer extends admin_ec_mainBaseWidgetConta
 	 */
 	function customerListLoop($index, $fetchedRow, $param)
 	{
-		global $gEnvManager;
-
 		$selected = '';
 		if ($fetchedRow['cc_id'] == $this->customerId){
 			$selected = 'selected';
