@@ -8,21 +8,20 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_ec_product_random_boxWidgetContainer.php 679 2008-06-03 11:46:01Z fishbone $
+ * @version    SVN: $Id: admin_ec_product_random_boxWidgetContainer.php 2253 2009-08-26 14:30:07Z fishbone $
  * @link       http://www.magic3.org
  */
-require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
+require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() .	'/product_randomDb.php');
 
-class admin_ec_product_random_boxWidgetContainer extends BaseWidgetContainer
+class admin_ec_product_random_boxWidgetContainer extends BaseAdminWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
 	private $productStatusData;		// 商品ステータスデータ
 	private $paramObj;		// ウィジェットデータオブジェクト
 	const DEFAULT_ITEM_COUNT = 8;				// デフォルトの表示項目数
-	const DEFAULT_TITLE = '商品ランダム表示';	// デフォルトのタイトル
 	
 	/**
 	 * コンストラクタ
@@ -60,10 +59,8 @@ class admin_ec_product_random_boxWidgetContainer extends BaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-		global $gEnvManager;
-
 		// デフォルト値
-		$langId	= $gEnvManager->getDefaultLanguage();
+		$langId	= $this->gEnv->getDefaultLanguage();
 		
 		// 商品ステータスを取得
 		$this->db->getAllProductStatus($langId, $this->productStatusData);
@@ -71,8 +68,6 @@ class admin_ec_product_random_boxWidgetContainer extends BaseWidgetContainer
 		$act = $request->trimValueOf('act');
 		if ($act == 'update'){		// 設定更新のとき
 			// 入力値を取得
-			$showTitle	= ($request->trimValueOf('show_title') == 'on') ? 1 : 0;			// タイトル表示
-			$title		= $request->valueOf('title');			// タイトル
 			$viewCount		= $request->valueOf('view_count');			// 表示項目数
 			$condition		= $request->valueOf('condition');			// 条件
 			// 商品ステータス
@@ -88,8 +83,6 @@ class admin_ec_product_random_boxWidgetContainer extends BaseWidgetContainer
 			$this->checkNumeric($viewCount, '商品取得数');
 			
 			if ($this->getMsgCount() == 0){			// エラーのないとき
-				$this->paramObj->showTitle	= $showTitle;	// タイトル表示
-				$this->paramObj->title	= $title;	// タイトル
 				$this->paramObj->viewCount	= $viewCount;	// 表示項目数
 				$this->paramObj->condition	= $condition;	// 条件
 				$this->paramObj->statusArray	= $statusArray;	// 商品ステータス
@@ -102,15 +95,11 @@ class admin_ec_product_random_boxWidgetContainer extends BaseWidgetContainer
 			}
 		} else {		// 初期表示の場合
 			// デフォルト値設定
-			$showTitle = 1;	// タイトル表示
-			$title = self::DEFAULT_TITLE;	// タイトル
 			$viewCount = self::DEFAULT_ITEM_COUNT;	// 表示項目数
 			$condition = 0;	// 条件
 			$statusArray = array();	// 商品ステータス
 			$this->paramObj = $this->getWidgetParamObj();
 			if (!empty($this->paramObj)){
-				$showTitle	= $this->paramObj->showTitle;	// タイトル表示
-				$title		= $this->paramObj->title;	// タイトル
 				$viewCount	= $this->paramObj->viewCount;	// 表示項目数
 				$condition	= $this->paramObj->condition;	// 条件
 				$statusArray = $this->paramObj->statusArray;	// 商品ステータス
@@ -120,19 +109,12 @@ class admin_ec_product_random_boxWidgetContainer extends BaseWidgetContainer
 		$this->createSelectStatus();
 		
 		// 画面にデータを埋め込む
-		if (!empty($showTitle)) $this->tmpl->addVar("_widget", "show_title",	'checked');
-		$this->tmpl->addVar("_widget", "title",	$title);// タイトル
 		$this->tmpl->addVar("_widget", "view_count",	$viewCount);// 表示項目数
 		if (empty($condition)){// 条件
 			$this->tmpl->addVar("_widget", "cond_all",	'checked');
 		} else {
 			$this->tmpl->addVar("_widget", "cond_selected",	'checked');
 		}
-		
-		// パスの設定
-		$this->tmpl->addVar("_widget", "widget_url", $gEnvManager->getCurrentWidgetRootUrl());	// ウィジェットのルートディレクトリ
-		$this->tmpl->addVar("_widget", "root_url", $gEnvManager->getRootUrl());
-		$this->tmpl->addVar("_widget", "widget_sc_url", $gEnvManager->getCurrentWidgetScriptsUrl());
 	}
 	/**
 	 * ステータス選択部を作成
