@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: pretty_photoWidgetContainer.php 3167 2010-05-28 04:52:15Z fishbone $
+ * @version    SVN: $Id: pretty_photoWidgetContainer.php 3425 2010-07-23 08:28:33Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -135,7 +135,7 @@ class pretty_photoWidgetContainer extends BaseWidgetContainer
 		$str  = '<!--[if IE 6]>' . M3_NL;
 		$str .= '<script src="' . $this->getUrl($this->gEnv->getCurrentWidgetScriptsUrl()) . '/' . '_DD_belatedPNG_0.0.7a-min.js"></script>' . M3_NL;
 		$str .= '<script>' . M3_NL;
-		$str .= 'DD_belatedPNG.fix(".pp_left,.pp_right,a.pp_close,a.pp_arrow_next,a.pp_arrow_previous,.pp_content,.pp_middle");' . M3_NL;
+		$str .= 'DD_belatedPNG.fix(".pp_left,.pp_right,a.pp_close,a.pp_arrow_next,a.pp_arrow_previous,.pp_content,.pp_middle,.pp_next,.pp_previous");' . M3_NL;
 		$str .= '</script>' . M3_NL;
 		$str .= '<![endif]-->' . M3_NL;
 		return $str;
